---
name: Feature Request
about: Suggest an idea for this project
title: ''
labels: enhancement
assignees: FabienLavocat
---

**Describe the feature request**

[Please describe what you expect from this feature.]
